==> downloads.html?file=gigkalender_v1.2.66_014.zip: gigkalender/guestbook/backend_showGuestbookEntry.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
      echo '<p class="Headline">'.$L_Headline35.':</p>';

      if ( !loggedIn() )
      {
        echo $L_003;
      }
      else
      {
        // Inhalt hier einfügen

  	 // Datensatz-Ausgabe festlegen
        	 $SQL_Befehl = "SELECT * FROM ".$prefix."guestbook Where GuestbookID = '$guestbookid'";

  	 // Saemtliche Datensatz-Ausgabe durchfuehren
  	 $resultat = mysql_db_query($db_name, $SQL_Befehl);

  	 while ($row = mysql_fetch_array($resultat))
          {
  	   extract($row);
  	   if ($ICQ==0) $ICQ='';
          }
          echo '
	   <table summary="ShowGig" class="Tabelle_GigAnzeigen">
  	     <tr>
    	       <td>'.$L_Date.':</td>
    	       <td>'.DatumMitUhrzeitAusTimestamp($Datum).'</td>
  	     </tr>
  	     <tr>
    	       <td>'.$L_114.':</td>
    	       <td>'.$Name.'</td>
  	     </tr>
  	     <tr>
    	       <td>'.$L_GuestbookLocation.':</td>
    	       <td>'.$Ort.'</td>
  	     </tr>
              <tr>
    	       <td>'.$L_115.':</td>
    	       <td><a href="mailto:'.$Email.'">'.$Email.'</a></td>
  	     </tr>
              <tr>
    	       <td>'.$L_116.':</td>
    	       <td><a href="'.$URL.'">'.$URL.'</a></td>
  	     </tr>  	     
  	     <tr>
    	       <td>'.$L_118.':</td>
    	       <td><a href="http://people.icq.com/people/about_me.php?uin='.$ICQ.'">'.$ICQ.'</a></td>
  	     </tr>
  	     <tr>
    	       <td>'.$L_119.':</td>
    	       <td>'.nl2br($Nachricht).'</td>
  	     </tr>
         <tr>
    	       <td>'.$L_138.':</td>
    	       <td>'.nl2br($Kommentar).'</td>
  	     </tr>  	     
	   </table>
          <a href="javascript:window.print()"><img src="images/print.gif" alt="'.$L_008.'" title="'.$L_008.'" /></a>
          <br />
          <input type="button" value="'.$L_Button04.'" onclick="history.go(-1)" class="button" />
          ';
        // Inhalt zuende
      }
    ?>

==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/guestbook/backend_showGuestbookEntry.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
      echo '<p class="Headline">'.$L_Headline35.':</p>';

      if ( !loggedIn() )
      {
        echo $L_003;
      }
      else
      {
        // Inhalt hier einfügen

  	 // Datensatz-Ausgabe festlegen
        	 $SQL_Befehl = "SELECT * FROM ".$prefix."guestbook Where GuestbookID = '$guestbookid'";

  	 // Saemtliche Datensatz-Ausgabe durchfuehren
  	 $resultat = mysqli_query($db, $SQL_Befehl);

  	 while ($row = mysqli_fetch_array($resultat))
          {
  	   extract($row);
  	   if ($ICQ==0) $ICQ='';
          }
          echo '
	   <table summary="ShowGig" class="Tabelle_GigAnzeigen">
  	     <tr>
    	       <td>'.$L_Date.':</td>
    	       <td>'.DatumMitUhrzeitAusTimestamp($Datum).'</td>
  	     </tr>
  	     <tr>
    	       <td>'.$L_114.':</td>
    	       <td>'.$Name.'</td>
  	     </tr>
  	     <tr>
    	       <td>'.$L_GuestbookLocation.':</td>
    	       <td>'.$Ort.'</td>
  	     </tr>
              <tr>
    	       <td>'.$L_115.':</td>
    	       <td><a href="mailto:'.$Email.'">'.$Email.'</a></td>
  	     </tr>
              <tr>
    	       <td>'.$L_116.':</td>
    	       <td><a href="'.$URL.'">'.$URL.'</a></td>
  	     </tr>  	     
  	     <tr>
    	       <td>'.$L_118.':</td>
    	       <td><a href="http://people.icq.com/people/about_me.php?uin='.$ICQ.'">'.$ICQ.'</a></td>
  	     </tr>
  	     <tr>
    	       <td>'.$L_119.':</td>
    	       <td>'.nl2br($Nachricht).'</td>
  	     </tr>
         <tr>
    	       <td>'.$L_138.':</td>
    	       <td>'.nl2br($Kommentar).'</td>
  	     </tr>  	     
	   </table>
          <a href="javascript:window.print()"><img src="images/print.gif" alt="'.$L_008.'" title="'.$L_008.'" /></a>
          <br />
          <input type="button" value="'.$L_Button04.'" onclick="history.go(-1)" class="button" />
          ';
        // Inhalt zuende
      }
    ?>
